#ifndef STRUCT_SOURCE_DATA_H
#define STRUCT_SOURCE_DATA_H

#include "struct_CPDD.h"
#include "struct_VList.h"

typedef struct source_data
{
	VList *file_list;
	CPDD *cpdd;
} SData;

#endif
